@@ -1,28 +1,16 @@
 """Tools for creating and manipulating neighborhood datasets."""
 
-import multiprocessing
 import os
 import pathlib
 from warnings import warn
 
 import geopandas as gpd
 import pandas as pd
-import quilt3
 from appdirs import user_data_dir
-from requests.exceptions import Timeout
-from shapely import wkb, wkt
 
 appname = "geosnap"
 appauthor = "geosnap"
 data_dir = user_data_dir(appname, appauthor)
-if not os.path.exists(data_dir):
-    pathlib.Path(data_dir).mkdir(parents=True, exist_ok=True)
-
-# look for local storage and create if missing
-try:
-    storage = quilt3.Package.browse("geosnap_data/storage")
-except FileNotFoundError:
-    storage = quilt3.Package()
 
 
 class _Map(dict):
@@ -57,51 +45,6 @@ class _Map(dict):
         del self.__dict__[key]
 
 
-def _deserialize_wkb(str):
-    return wkb.loads(str, hex=True)
-
-
-def _deserialize_wkt(str):
-    return wkt.loads(str)
-
-
-def _convert_gdf(df):
-    """Convert DataFrame to GeoDataFrame.
-
-    DataFrame to GeoDataFrame by converting wkt/wkb geometry representation
-    back to Shapely object.
-
-    Parameters
-    ----------
-    df : pandas.DataFrame
-        dataframe with column named either "wkt" or "wkb" that stores
-        geometric information as well-known text or well-known binary,
-        (hex encoded) respectively.
-
-    Returns
-    -------
-    geopandas.GeoDataFrame
-        geodataframe with converted `geometry` column.
-
-    """
-    df = df.copy()
-    df.reset_index(inplace=True, drop=True)
-
-    if "wkt" in df.columns.tolist():
-        with multiprocessing.Pool() as P:
-            df["geometry"] = P.map(_deserialize_wkt, df["wkt"])
-        df = df.drop(columns=["wkt"])
-
-    else:
-        with multiprocessing.Pool() as P:
-            df["geometry"] = P.map(_deserialize_wkb, df["wkb"])
-        df = df.drop(columns=["wkb"])
-
-    df = gpd.GeoDataFrame(df)
-    df.crs = {"init": "epsg:4326"}
-
-    return df
-
 
 class DataStore:
     """Storage for geosnap data. Currently supports US Census data.
@@ -113,39 +56,12 @@ class DataStore:
     """
 
     def __init__(self):
-        """Instantiate a new DataStore object."""
-
-        try: # if any of these aren't found, stream them insteead
-            administrative = quilt3.Package.browse("census/administrative")
-            tracts_cartographic = quilt3.Package.browse("census/tracts_cartographic")
-        except FileNotFoundError:
-            warn(
-                "Unable to locate local census data. Streaming instead.\n"
-                "If you plan to use census data repeatedly you can store it locally "
-                "with the io.store_census function for better performance"
-            )
-            try:
-                tracts_cartographic = quilt3.Package.browse(
-                    "census/tracts_cartographic", "s3://spatial-ucr"
-                )
-                administrative = quilt3.Package.browse(
-                    "census/administrative", "s3://spatial-ucr"
-                )
-
-            except Timeout:
-                warn(
-                    "Unable to locate local census data and unable to reach s3 bucket."
-                    "You will be unable to use built-in data during this session. "
-                    "If you need these data, please try downloading a local copy "
-                    "with the io.store_census function, then restart your "
-                    "python kernel and try again."
-                )
-        self.tracts_cartographic = tracts_cartographic
-        self.administrative = administrative
+        self
 
     def __dir__(self):
 
         atts = [
+            "acs",
             "blocks_2000",
             "blocks_2010",
             "codebook",
@@ -162,15 +78,48 @@ class DataStore:
 
         return atts
 
-    def blocks_2000(self, states=None, convert=True, fips=None):
+    def acs(self, year=2018, level="tract", states=None):
+        """American Community Survey Data.
+
+        Parameters
+        ----------
+        year : str
+            vingage of ACS release.
+        level : str
+            geographic level
+        states : list, optional
+            subset of states (as 2-digit fips) to return 
+
+        Returns
+        -------
+        geopandas.GeoDataFrame
+            geodataframe of ACS data indexed by FIPS code
+        """
+        try:
+            t = gpd.read_parquet(
+                pathlib.Path(data_dir, "acs", f"acs_{year}_{level}.parquet")
+            )
+        except Exception:
+            warn(
+                "streaming remote data. Use `geosnap.io.store_acs() to store the data locally for better performance"
+            )
+            t = gpd.read_parquet(
+                f"s3://spatial-ucr/census/acs/acs_{year}_{level}.parquet"
+            )
+        t = t.reset_index().rename(columns={"GEOID": "geoid"})
+
+        if states:
+            t = t[t.geoid.str[:2].isin(states)]
+        t["year"] = year
+        return t
+
+    def blocks_2000(self, states=None, fips=None):
         """Census blocks for 2000.
 
         Parameters
         ----------
         states : list-like
             list of state fips codes to return as a datafrrame.
-        convert : bool
-        if True, return geodataframe, else return dataframe (the default is True).
 
         Returns
         -------
@@ -180,52 +129,40 @@ class DataStore:
             stored as well-known binary on the 'wkb' column.
 
         """
-        try:
-            blocks_2000 = quilt3.Package.browse("census/blocks_2000") # if any of these aren't found, stream them instead
-        except FileNotFoundError:
-            warn(
-                "Unable to locate local census 2000 block data. Streaming instead.\n"
-                "If you plan to use census data repeatedly you can store it locally "
-                "with the io.store_blocks_2000 function for better performance"
-            )
-            try:
-                blocks_2000 = quilt3.Package.browse(
-                    "census/blocks_2000", "s3://spatial-ucr"
-                )
-
-            except Timeout:
-                warn(
-                    "Unable to locate local census data and unable to reach s3 bucket."
-                    "You will be unable to use built-in data during this session. "
-                    "Try downloading a local copy with the io.store_blocks_2000 function,"
-                    "then restart your python kernel and try again."
-                )
-
-        if isinstance(states, (str,)):
-            states = [states]
-        if isinstance(states, (int,)):
+        if isinstance(states, (str, int)):
             states = [states]
         blks = {}
         for state in states:
-            blks[state] = blocks_2000[f"{state}.parquet"]()
+            try:
+                blks[state] = gpd.read_parquet(
+                    pathlib.Path(data_dir, "blocks_2000", f"{state}.parquet")
+                )
+            except Exception:
+                warn(
+                    "Unable to locate local census 2010 block data. Streaming instead.\n"
+                    "If you plan to use census data repeatedly you can store it locally "
+                    "with the io.store_blocks_2010 function for better performance"
+                )
+                blks[state] = gpd.read_parquet(
+                    f"s3://spatial-ucr/census/blocks_2000/{state}.parquet"
+                )
+
             if fips:
                 blks[state] = blks[state][blks[state]["geoid"].str.startswith(fips)]
+
             blks[state]["year"] = 2000
         blocks = list(blks.values())
-        blocks = pd.concat(blocks, sort=True)
-        if convert:
-            return _convert_gdf(blocks)
+        blocks = gpd.GeoDataFrame(pd.concat(blocks, sort=True))
+
         return blocks
 
-    def blocks_2010(self, states=None, convert=True, fips=None):
+    def blocks_2010(self, states=None, fips=None):
         """Census blocks for 2010.
 
         Parameters
         ----------
         states : list-like
             list of state fips codes to return as a datafrrame.
-        convert : bool
-        if True, return geodataframe, else return dataframe (the default is True).
 
         Returns
         -------
@@ -235,52 +172,40 @@ class DataStore:
             stored as well-known binary on the 'wkb' column.
 
         """
-        try:
-            blocks_2010 = quilt3.Package.browse("census/blocks_2010")  # if any of these aren't found, stream them instead
-        except FileNotFoundError:
-            warn(
-                "Unable to locate local census 2010 block data. Streaming instead.\n"
-                "If you plan to use census data repeatedly you can store it locally "
-                "with the io.store_blocks_2010 function for better performance"
-            )
-            try:
-                blocks_2010 = quilt3.Package.browse(
-                    "census/blocks_2010", "s3://spatial-ucr"
-                )
-
-            except Timeout:
-                warn(
-                    "Unable to locate local census data and unable to reach s3 bucket."
-                    "You will be unable to use built-in data during this session. "
-                    "If you need these data, please try downloading a local copy "
-                    "with the io.store_blocks_2010 function, then restart your "
-                    "python kernel and try again."
-                )
-
         if isinstance(states, (str, int)):
             states = [states]
         blks = {}
         for state in states:
-            blks[state] = blocks_2010[f"{state}.parquet"]()
+            try:
+                blks[state] = gpd.read_parquet(
+                    pathlib.Path(data_dir, "blocks_2010", f"{state}.parquet")
+                )
+            except Exception:
+                warn(
+                    "Unable to locate local census 2010 block data. Streaming instead.\n"
+                    "If you plan to use census data repeatedly you can store it locally "
+                    "with the io.store_blocks_2010 function for better performance"
+                )
+                blks[state] = gpd.read_parquet(
+                    f"s3://spatial-ucr/census/blocks_2010/{state}.parquet"
+                )
+
             if fips:
                 blks[state] = blks[state][blks[state]["geoid"].str.startswith(fips)]
 
             blks[state]["year"] = 2010
         blocks = list(blks.values())
-        blocks = pd.concat(blocks, sort=True)
-        if convert:
-            return _convert_gdf(blocks)
+        blocks = gpd.GeoDataFrame(pd.concat(blocks, sort=True))
+
         return blocks
 
-    def tracts_1990(self, states=None, convert=True):
+    def tracts_1990(self, states=None):
         """Nationwide Census Tracts as drawn in 1990 (cartographic 500k).
 
         Parameters
         ----------
         states : list-like
             list of state fips to subset the national dataframe
-        convert : bool
-            if True, return geodataframe, else return dataframe (the default is True).
 
         Returns
         -------
@@ -289,24 +214,29 @@ class DataStore:
             stored as well-known binary on the 'wkb' column.
 
         """
-        t = self.tracts_cartographic["tracts_1990_500k.parquet"]()
+        try:
+            t = gpd.read_parquet(pathlib.Path(data_dir, "tracts_1990_500k.parquet"))
+        except Exception:
+            warn(
+                "streaming remote data. Use `geosnap.io.store_census() to store the data locally for better performance"
+            )
+            t = gpd.read_parquet(
+                "s3://spatial-ucr/census/tracts_cartographic/tracts_1990_500k.parquet"
+            )
+
         if states:
             t = t[t.geoid.str[:2].isin(states)]
         t["year"] = 1990
-        if convert:
-            return _convert_gdf(t)
-        else:
-            return t
 
-    def tracts_2000(self, states=None, convert=True):
+        return t
+
+    def tracts_2000(self, states=None):
         """Nationwide Census Tracts as drawn in 2000 (cartographic 500k).
 
         Parameters
         ----------
         states : list-like
             list of state fips to subset the national dataframe
-        convert : bool
-            if True, return geodataframe, else return dataframe (the default is True).
 
         Returns
         -------
@@ -315,24 +245,30 @@ class DataStore:
             stored as well-known binary on the 'wkb' column.
 
         """
-        t = self.tracts_cartographic["tracts_2000_500k.parquet"]()
+        try:
+            t = gpd.read_parquet(pathlib.Path(data_dir, "tracts_2000_500k.parquet"))
+        except Exception:
+            warn(
+                "streaming remote data. Use `geosnap.io.store_census() to store the data locally for better performance"
+            )
+            t = gpd.read_parquet(
+                "s3://spatial-ucr/census/tracts_cartographic/tracts_2000_500k.parquet"
+            )
         if states:
             t = t[t.geoid.str[:2].isin(states)]
         t["year"] = 2000
-        if convert:
-            return _convert_gdf(t)
-        else:
-            return t
 
-    def tracts_2010(self, states=None, convert=True):
+        return t
+
+    def tracts_2010(
+        self, states=None,
+    ):
         """Nationwide Census Tracts as drawn in 2010 (cartographic 500k).
 
         Parameters
         ----------
         states : list-like
             list of state fips to subset the national dataframe
-        convert : bool
-            if True, return geodataframe, else return dataframe (the default is True).
 
         Returns
         -------
@@ -341,25 +277,27 @@ class DataStore:
             stored as well-known binary on the 'wkb' column.
 
         """
-        t = self.tracts_cartographic["tracts_2010_500k.parquet"]()
+        try:
+            t = gpd.read_parquet(pathlib.Path(data_dir, "tracts_2010_500k.parquet"))
+        except Exception:
+            warn(
+                "streaming remote data. Use `geosnap.io.store_census() to store the data locally for better performance"
+            )
+            t = gpd.read_parquet(
+                "s3://spatial-ucr/census/tracts_cartographic/tracts_2010_500k.parquet"
+            )
+
         if states:
             t = t[t.geoid.str[:2].isin(states)]
         t["year"] = 2010
-        if convert:
-            return _convert_gdf(t)
-        else:
-            return t
+        return t
 
-    def msas(self, convert=True):
-        """Metropolitan Statistical Areas as drawn in 2010.
+    def msas(self):
+        """Metropolitan Statistical Areas as drawn in 2020.
 
         Data come from the U.S. Census Bureau's most recent TIGER/LINE files
-        https://www.census.gov/cgi-bin/geo/shapefiles/index.php?year=2018&layergroup=Core+Based+Statistical+Areas
+        https://www.census.gov/cgi-bin/geo/shapefiles/index.php?year=2020&layergroup=Core+Based+Statistical+Areas
 
-        Parameters
-        ----------
-        convert : bool
-            if True, return geodataframe, else return dataframe (the default is True).
 
         Returns
         -------
@@ -368,20 +306,18 @@ class DataStore:
             stored as well-known binary on the 'wkb' column.
 
         """
-        if convert:
-            return _convert_gdf(
-                self.administrative["msas.parquet"]().sort_values(by="name")
+        try:
+            return gpd.read_parquet(pathlib.Path(data_dir, "msas.parquet")).sort_values(
+                by="name"
             )
-        return self.administrative["msas.parquet"]().sort_values(by="name")
+        except Exception:
+            return gpd.read_parquet(
+                "s3://spatial-ucr/census/administrative/msas.parquet"
+            ).sort_values(by="name")
 
-    def states(self, convert=True):
+    def states(self):
         """States.
 
-        Parameters
-        ----------
-        convert : bool
-            if True, return geodataframe, else return dataframe (the default is True).
-
         Returns
         -------
         pandas.DataFrame or geopandas.GeoDataFrame
@@ -389,9 +325,12 @@ class DataStore:
             stored as well-known binary on the 'wkb' column.
 
         """
-        if convert:
-            return _convert_gdf(self.administrative["states.parquet"]())
-        return self.administrative["states.parquet"]()
+        try:
+            return gpd.read_parquet(pathlib.Path(data_dir, "states.parquet"))
+        except Exception:
+            return gpd.read_parquet(
+                "s3://spatial-ucr/census/administrative/states.parquet"
+            )
 
     def counties(self):
         """Nationwide counties as drawn in 2010.
@@ -408,7 +347,12 @@ class DataStore:
             stored as well-known binary on the 'wkb' column.
 
         """
-        return _convert_gdf(self.administrative["counties.parquet"]())
+        try:
+            return gpd.read_parquet(pathlib.Path(data_dir, "counties.parquet"))
+        except Exception:
+            return gpd.read_parquet(
+                "s3://spatial-ucr/census/administrative/counties.parquet"
+            )
 
     def msa_definitions(self):
         """2010 Metropolitan Statistical Area definitions.
@@ -422,7 +366,12 @@ class DataStore:
             dataframe that stores state/county --> MSA crosswalk definitions.
 
         """
-        return self.administrative["msa_definitions.parquet"]()
+        try:
+            return pd.read_parquet(pathlib.Path(data_dir, "msa_definitions.parquet"))
+        except Exception:
+            return pd.read_parquet(
+                "s3://spatial-ucr/census/administrative/msa_definitions.parquet"
+            )
 
     def ltdb(self):
         """Longitudinal Tract Database (LTDB).
@@ -434,7 +383,7 @@ class DataStore:
 
         """
         try:
-            return storage["ltdb"]()
+            return pd.read_parquet(pathlib.Path(data_dir, "ltdb.parquet"))
         except KeyError:
             print(
                 "Unable to locate LTDB data. Try saving the data again "
@@ -451,7 +400,7 @@ class DataStore:
 
         """
         try:
-            return storage["ncdb"]()
+            return pd.read_parquet(pathlib.Path(data_dir, "ncdb.parquet"))
         except KeyError:
             print(
                 "Unable to locate NCDB data. Try saving the data again "
